package com.bpcl.lpg.core.encryption.pgp;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.io.IOException;
import java.util.Objects;
import java.io.FileInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStream;
import java.io.BufferedOutputStream;
import java.io.FileOutputStream;
import java.io.File;
import org.apache.log4j.Logger;
import javax.annotation.Resource;
import de.hybris.platform.servicelayer.config.ConfigurationService;

public class DefaultLpgPgpKeys
{
    @Resource(name = "configurationService")
    private ConfigurationService configurationService;
    private Logger LOG;
    
    public DefaultLpgPgpKeys() {
        this.LOG = Logger.getLogger((Class)DefaultLpgPgpKeys.class);
    }
    
    public File getEncryptedFile(final String publicKey, final File unEncryptedFile, final String encryptFileName) {
        final File encryptedFile = new File(encryptFileName);
        this.fileEncryption(unEncryptedFile, encryptedFile.getPath(), publicKey);
        return encryptedFile;
    }
    
    public boolean fileEncryption(final File unencryptedFile, final String tempFilePath, final String publicKeyProperty) {
        this.LOG.info((Object)"Entering encryptFile");
        OutputStream out = null;
        InputStream plainInputData = null;
        InputStream publicKeyInputData = null;
        try {
            out = new BufferedOutputStream(new FileOutputStream(unencryptedFile.getPath()));
            final ByteArrayOutputStream baos = new ByteArrayOutputStream();
            final PGPMessageEncryptor pgp = new PGPMessageEncryptor();
            final File initialFile = new File(tempFilePath);
            plainInputData = new FileInputStream(initialFile);
            final File publicKey = new File(publicKeyProperty);
            publicKeyInputData = new FileInputStream(publicKey);
            pgp.encrypt(publicKeyInputData, tempFilePath, plainInputData, baos);
            out.write(baos.toByteArray());
            this.LOG.info("Encryption Successful " + unencryptedFile.getPath());
        }
        catch (final Exception e) {
            this.LOG.error("Error signing and encrypting file: " + e);
            if (Objects.nonNull(out)) {
                try {
                    out.close();
                }
                catch (final IOException e2) {
                    this.LOG.error("Error closing output stream during encryption: " + e2);
                }
            }
            if (Objects.nonNull(plainInputData)) {
                try {
                    plainInputData.close();
                }
                catch (final IOException e2) {
                    this.LOG.error("Error closing input stream during encryption: " + e2);
                }
            }
            if (Objects.nonNull(publicKeyInputData)) {
                try {
                    publicKeyInputData.close();
                }
                catch (final IOException e2) {
                    this.LOG.error("Error closing public key stream during encryption: " + e2);
                }
            }
        }
        finally {
            if (Objects.nonNull(out)) {
                try {
                    out.close();
                }
                catch (final IOException e3) {
                    this.LOG.error("Error closing output stream during encryption: " + e3);
                }
            }
            if (Objects.nonNull(plainInputData)) {
                try {
                    plainInputData.close();
                }
                catch (final IOException e3) {
                    this.LOG.error("Error closing input stream during encryption: " + e3);
                }
            }
            if (Objects.nonNull(publicKeyInputData)) {
                try {
                    publicKeyInputData.close();
                }
                catch (final IOException e3) {
                    this.LOG.error("Error closing public key stream during encryption: " + e3);
                }
            }
        }
        return true;
    }
    
    public InputStream decryptAndVerify(final String encryptedFileName, final String privateKeyProperty, final String passPhareKeyProperty) {
        final PGPMessageEncryptor pgpencrpyt = new PGPMessageEncryptor();
        final File initialFile = new File(this.configurationService.getConfiguration().getString(privateKeyProperty));
        InputStream byteInpStr = null;
        try (final InputStream cepPrivkey = new FileInputStream(initialFile);
             final ByteArrayOutputStream bytearroutstr = new ByteArrayOutputStream();
             final InputStream fileEcryptStr = new FileInputStream(encryptedFileName)) {
            this.LOG.debug((Object)"Entering decryptFile");
            pgpencrpyt.decrypt(this.configurationService.getConfiguration().getString(passPhareKeyProperty), cepPrivkey, fileEcryptStr, bytearroutstr);
            byteInpStr = new ByteArrayInputStream(bytearroutstr.toByteArray());
            this.LOG.debug((Object)"Completed decryptFile");
        }
        catch (final Exception exception) {
            this.LOG.error("x " + exception.getMessage());
        }
        return byteInpStr;
    }
}
